nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ch0statClr

Struct Ch0statClr 

#[repr(transparent)]
pub struct Ch0statClr(pub u32);
DCP channel 0 status register

Tuple Fields

0: u32

Implementations

Source

impl Ch0statClr

pub const fn hash_mismatch(&self) -> bool

This bit indicates that a hashing check operation mismatched for the control packets that enable the HASH_CHECK bit

pub const fn set_hash_mismatch(&mut self, val: bool)

This bit indicates that a hashing check operation mismatched for the control packets that enable the HASH_CHECK bit

pub const fn error_setup(&self) -> bool

This bit indicates that the hardware detected an invalid programming configuration (such as a buffer length that is not a multiple of the natural data size for the operation)

pub const fn set_error_setup(&mut self, val: bool)

This bit indicates that the hardware detected an invalid programming configuration (such as a buffer length that is not a multiple of the natural data size for the operation)

pub const fn error_packet(&self) -> bool

This bit indicates that a bus error occurred when reading the packet or payload, or when writing the status back to the packet payload

pub const fn set_error_packet(&mut self, val: bool)

This bit indicates that a bus error occurred when reading the packet or payload, or when writing the status back to the packet payload

pub const fn error_src(&self) -> bool

This bit indicates that a bus error occurred when reading from the source buffer

pub const fn set_error_src(&mut self, val: bool)

This bit indicates that a bus error occurred when reading from the source buffer

pub const fn error_dst(&self) -> bool

This bit indicates that a bus error occurred when storing to the destination buffer

pub const fn set_error_dst(&mut self, val: bool)

This bit indicates that a bus error occurred when storing to the destination buffer

pub const fn error_pagefault(&self) -> bool

This bit indicates that a page fault occurred while converting a virtual address to a physical address

pub const fn set_error_pagefault(&mut self, val: bool)

This bit indicates that a page fault occurred while converting a virtual address to a physical address

pub const fn error_code(&self) -> Ch0statClrErrorCode

Indicates the additional error codes for some of the error conditions

pub const fn set_error_code(&mut self, val: Ch0statClrErrorCode)

Indicates the additional error codes for some of the error conditions

pub const fn tag(&self) -> u8

Indicates the tag from the last completed packet in the command structure

pub const fn set_tag(&mut self, val: u8)

Indicates the tag from the last completed packet in the command structure