#[repr(transparent)]pub struct Ch1sema(pub u32);Expand description
DCP channel 1 semaphore register
Tuple Fields
0: u32Implementations
Sourceimpl Ch1sema
impl Ch1sema
Sourcepub const fn increment(&self) -> u8
pub const fn increment(&self) -> u8
The value written to this field is added to the semaphore count in an atomic way, such that the simultaneous software adds and the DCP hardware substracts happening on the same clock are protected
Sourcepub const fn set_increment(&mut self, val: u8)
pub const fn set_increment(&mut self, val: u8)
The value written to this field is added to the semaphore count in an atomic way, such that the simultaneous software adds and the DCP hardware substracts happening on the same clock are protected