nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ch2optsSet

Struct Ch2optsSet 

#[repr(transparent)]
pub struct Ch2optsSet(pub u32);
DCP channel 2 options register

Tuple Fields

0: u32

Implementations

Source

impl Ch2optsSet

pub const fn recovery_timer(&self) -> u16

This field indicates the recovery time for the channel

pub const fn set_recovery_timer(&mut self, val: u16)

This field indicates the recovery time for the channel