nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ctrl

Struct Ctrl 

#[repr(transparent)]
pub struct Ctrl(pub u32);
DCP control register 0

Tuple Fields

0: u32

Implementations

Source

impl Ctrl

pub const fn channel_interrupt_enable(&self) -> CtrlChannelInterruptEnable

Per-channel interrupt enable bit

pub const fn set_channel_interrupt_enable( &mut self, val: CtrlChannelInterruptEnable, )

Per-channel interrupt enable bit

pub const fn enable_context_switching(&self) -> bool

Enable automatic context switching for the channels

pub const fn set_enable_context_switching(&mut self, val: bool)

Enable automatic context switching for the channels

pub const fn enable_context_caching(&self) -> bool

The software must set this bit to enable the caching of contexts between the operations

pub const fn set_enable_context_caching(&mut self, val: bool)

The software must set this bit to enable the caching of contexts between the operations

pub const fn gather_residual_writes(&self) -> bool

The software must set this bit to enable the ragged writes to the unaligned buffers to be gathered between multiple write operations

pub const fn set_gather_residual_writes(&mut self, val: bool)

The software must set this bit to enable the ragged writes to the unaligned buffers to be gathered between multiple write operations

pub const fn present_sha(&self) -> CtrlPresentSha

Indicates whether the SHA1/SHA2 functions are present.

pub const fn set_present_sha(&mut self, val: CtrlPresentSha)

Indicates whether the SHA1/SHA2 functions are present.

pub const fn present_crypto(&self) -> CtrlPresentCrypto

Indicates whether the crypto (cipher/hash) functions are present.

pub const fn set_present_crypto(&mut self, val: CtrlPresentCrypto)

Indicates whether the crypto (cipher/hash) functions are present.

pub const fn clkgate(&self) -> bool

This bit must be set to zero for a normal operation

pub const fn set_clkgate(&mut self, val: bool)

This bit must be set to zero for a normal operation

pub const fn sftrst(&self) -> bool

Set this bit to zero to enable a normal DCP operation

pub const fn set_sftrst(&mut self, val: bool)

Set this bit to zero to enable a normal DCP operation