nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Packet1

Struct Packet1 

#[repr(transparent)]
pub struct Packet1(pub u32);
DCP work packet 1 status register

Tuple Fields

0: u32

Implementations

Source

impl Packet1

pub const fn interrupt(&self) -> bool

Reflects whether the channel must issue an interrupt upon the completion of the packet.

pub const fn set_interrupt(&mut self, val: bool)

Reflects whether the channel must issue an interrupt upon the completion of the packet.

pub const fn decr_semaphore(&self) -> bool

Reflects whether the channel’s semaphore must be decremented at the end of the current operation

pub const fn set_decr_semaphore(&mut self, val: bool)

Reflects whether the channel’s semaphore must be decremented at the end of the current operation

pub const fn chain(&self) -> bool

Reflects whether the next command pointer register must be loaded into the channel’s current descriptor pointer

pub const fn set_chain(&mut self, val: bool)

Reflects whether the next command pointer register must be loaded into the channel’s current descriptor pointer

pub const fn chain_contiguous(&self) -> bool

Reflects whether the next packet’s address is located following this packet’s payload.

pub const fn set_chain_contiguous(&mut self, val: bool)

Reflects whether the next packet’s address is located following this packet’s payload.

pub const fn enable_memcopy(&self) -> bool

Reflects whether the selected memory-copy (memcopy) function should be enabled for this operation.

pub const fn set_enable_memcopy(&mut self, val: bool)

Reflects whether the selected memory-copy (memcopy) function should be enabled for this operation.

pub const fn enable_cipher(&self) -> bool

Reflects whether the selected cipher function must be enabled for this operation.

pub const fn set_enable_cipher(&mut self, val: bool)

Reflects whether the selected cipher function must be enabled for this operation.

pub const fn enable_hash(&self) -> bool

Reflects whether the selected hashing function must be enabled for this operation.

pub const fn set_enable_hash(&mut self, val: bool)

Reflects whether the selected hashing function must be enabled for this operation.

pub const fn enable_blit(&self) -> bool

Reflects whether the DCP must perform a blit operation

pub const fn set_enable_blit(&mut self, val: bool)

Reflects whether the DCP must perform a blit operation

pub const fn cipher_encrypt(&self) -> CipherEncrypt

When the cipher block is enabled, this bit indicates whether the operation is encryption or decryption

pub const fn set_cipher_encrypt(&mut self, val: CipherEncrypt)

When the cipher block is enabled, this bit indicates whether the operation is encryption or decryption

pub const fn cipher_init(&self) -> bool

Reflects whether the cipher block must load the initialization vector from the payload for this operation

pub const fn set_cipher_init(&mut self, val: bool)

Reflects whether the cipher block must load the initialization vector from the payload for this operation

pub const fn otp_key(&self) -> bool

Reflects whether a hardware-based key must be used

pub const fn set_otp_key(&mut self, val: bool)

Reflects whether a hardware-based key must be used

pub const fn payload_key(&self) -> bool

When set, it indicates the payload contains the key

pub const fn set_payload_key(&mut self, val: bool)

When set, it indicates the payload contains the key

pub const fn hash_init(&self) -> bool

Reflects whether the current hashing block is the initial block in the hashing operation, so the hash registers must be initialized before the operation

pub const fn set_hash_init(&mut self, val: bool)

Reflects whether the current hashing block is the initial block in the hashing operation, so the hash registers must be initialized before the operation

pub const fn hash_term(&self) -> bool

Reflects whether the current hashing block is the final block in the hashing operation, so the hash padding must be applied by the hardware

pub const fn set_hash_term(&mut self, val: bool)

Reflects whether the current hashing block is the final block in the hashing operation, so the hash padding must be applied by the hardware

pub const fn check_hash(&self) -> bool

Reflects whether the calculated hash value must be compared to the hash provided in the payload.

pub const fn set_check_hash(&mut self, val: bool)

Reflects whether the calculated hash value must be compared to the hash provided in the payload.

pub const fn hash_output(&self) -> HashOutput

When the hashing is enabled, this bit controls whether the input or output data is hashed.

pub const fn set_hash_output(&mut self, val: HashOutput)

When the hashing is enabled, this bit controls whether the input or output data is hashed.

pub const fn constant_fill(&self) -> bool

When this bit is set (MEMCOPY and BLIT modes only), the DCP simply fills the destination buffer with the value found in the source address field

pub const fn set_constant_fill(&mut self, val: bool)

When this bit is set (MEMCOPY and BLIT modes only), the DCP simply fills the destination buffer with the value found in the source address field

pub const fn test_sema_irq(&self) -> bool

This bit is used to test the channel semaphore transition to 0. FOR TEST USE ONLY!

pub const fn set_test_sema_irq(&mut self, val: bool)

This bit is used to test the channel semaphore transition to 0. FOR TEST USE ONLY!

pub const fn key_byteswap(&self) -> bool

Reflects whether the DCP engine swaps the key bytes (big-endian key).

pub const fn set_key_byteswap(&mut self, val: bool)

Reflects whether the DCP engine swaps the key bytes (big-endian key).

pub const fn key_wordswap(&self) -> bool

Reflects whether the DCP engine swaps the key words (big-endian key).

pub const fn set_key_wordswap(&mut self, val: bool)

Reflects whether the DCP engine swaps the key words (big-endian key).

pub const fn input_byteswap(&self) -> bool

Reflects whether the DCP engine byteswaps the input data (big-endian data).

pub const fn set_input_byteswap(&mut self, val: bool)

Reflects whether the DCP engine byteswaps the input data (big-endian data).

pub const fn input_wordswap(&self) -> bool

Reflects whether the DCP engine wordswaps the input data (big-endian data).

pub const fn set_input_wordswap(&mut self, val: bool)

Reflects whether the DCP engine wordswaps the input data (big-endian data).

pub const fn output_byteswap(&self) -> bool

Reflects whether the DCP engine byteswaps the output data (big-endian data).

pub const fn set_output_byteswap(&mut self, val: bool)

Reflects whether the DCP engine byteswaps the output data (big-endian data).

pub const fn output_wordswap(&self) -> bool

Reflects whether the DCP engine wordswaps the output data (big-endian data).

pub const fn set_output_wordswap(&mut self, val: bool)

Reflects whether the DCP engine wordswaps the output data (big-endian data).

pub const fn tag(&self) -> u8

Packet Tag

pub const fn set_tag(&mut self, val: u8)

Packet Tag