nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Packet2

Struct Packet2 

#[repr(transparent)]
pub struct Packet2(pub u32);
DCP work packet 2 status register

Tuple Fields

0: u32

Implementations

Source

impl Packet2

pub const fn cipher_select(&self) -> CipherSelect

Cipher selection field

pub const fn set_cipher_select(&mut self, val: CipherSelect)

Cipher selection field

pub const fn cipher_mode(&self) -> CipherMode

Cipher mode selection field. Reflects the mode of operation for the cipher operations.

pub const fn set_cipher_mode(&mut self, val: CipherMode)

Cipher mode selection field. Reflects the mode of operation for the cipher operations.

pub const fn key_select(&self) -> KeySelect

Key selection field

pub const fn set_key_select(&mut self, val: KeySelect)

Key selection field

pub const fn hash_select(&self) -> HashSelect

Hash Selection Field

pub const fn set_hash_select(&mut self, val: HashSelect)

Hash Selection Field

pub const fn cipher_cfg(&self) -> u8

Cipher configuration bits. Optional configuration bits are required for the ciphers.

pub const fn set_cipher_cfg(&mut self, val: u8)

Cipher configuration bits. Optional configuration bits are required for the ciphers.