nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Packet5

Struct Packet5 

#[repr(transparent)]
pub struct Packet5(pub u32);
DCP work packet 5 status register

Tuple Fields

0: u32

Implementations

Source

impl Packet5

pub const fn count(&self) -> u32

Byte count register. This value is the working value and updates as the operation proceeds.

pub const fn set_count(&mut self, val: u32)

Byte count register. This value is the working value and updates as the operation proceeds.