nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

StatSet

Struct StatSet 

#[repr(transparent)]
pub struct StatSet(pub u32);
DCP status register

Tuple Fields

0: u32

Implementations

Source

impl StatSet

pub const fn irq(&self) -> u8

Indicates which channels have pending interrupt requests

pub const fn set_irq(&mut self, val: u8)

Indicates which channels have pending interrupt requests

pub const fn ready_channels(&self) -> StatSetReadyChannels

Indicates which channels are ready to proceed with a transfer (the active channel is also included)

pub const fn set_ready_channels(&mut self, val: StatSetReadyChannels)

Indicates which channels are ready to proceed with a transfer (the active channel is also included)

pub const fn cur_channel(&self) -> StatSetCurChannel

Current (active) channel (encoded)

pub const fn set_cur_channel(&mut self, val: StatSetCurChannel)

Current (active) channel (encoded)

pub const fn otp_key_ready(&self) -> bool

When set, it indicates that the OTP key is shifted from the fuse block and is ready for use.

pub const fn set_otp_key_ready(&mut self, val: bool)

When set, it indicates that the OTP key is shifted from the fuse block and is ready for use.